<?php
/**
 * Sonsa functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package Sonsa
 */
 
/**
 * The current version of the theme.
 */
define( 'SONSA_VERSION', '1.1.0' );

if ( ! function_exists( 'sonsa_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function sonsa_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Sonsa, use a find and replace
	 * to change 'sonsa' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'sonsa', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 960, 9999, false );
	
	// Add custom image sizes.
	add_image_size( 'sonsa-site-logo', 192, 192, true );
	add_image_size( 'sonsa-thumbnail', 150, 150, true );
	
	// This theme uses wp_nav_menu() in three locations.
	register_nav_menus( array(
		'primary'   => esc_html_x( 'Primary', 'nav menu location', 'sonsa' ),
		'social'    => esc_html_x( 'Social', 'nav menu location', 'sonsa' ),
		'portfolio' => esc_html_x( 'Portfolio', 'nav menu location', 'sonsa' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'audio',
		'chat',
		'gallery',
		'image',
		'link',
		'quote',
		'status',
		'video',
	) );
	
	// Add support for logo.
	add_theme_support( 'custom-logo', apply_filters( 'sonsa_custom_logo_args', array(
		'height' => 192,
		'width'  => 192,
	) ) );
	
	// Add theme support for refresh widgets. 
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', 'genericons/genericons.css', sonsa_fonts_url() ) );

}
endif; // sonsa_setup
add_action( 'after_setup_theme', 'sonsa_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sonsa_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'sonsa_content_width', 960 );
}
add_action( 'after_setup_theme', 'sonsa_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sonsa_widgets_init() {
	
	// Primary widget arguments.
	$sidebar_primary_args = array(
		'id'            => 'sidebar-1',
		'name'          => esc_html_x( 'Primary', 'sidebar', 'sonsa' ),
		'description'   => esc_html__( 'The main sidebar. It is displayed in the off-canvas menu.', 'sonsa' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	);

	// Header widget arguments.	
	$sidebar_header_args = array(
		'id'            => 'header',
		'name'          => esc_html_x( 'Header', 'sidebar', 'sonsa' ),
		'description'   => esc_html__( 'A widget area located in the header of the site. For optimal layout it is recommended to use only one short widget.', 'sonsa' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>'
	);

	// Register sidebars.
	register_sidebar( $sidebar_primary_args );
	register_sidebar( $sidebar_header_args );
	
}
add_action( 'widgets_init', 'sonsa_widgets_init' );

/**
 * Return the Google font stylesheet URL
 */
function sonsa_fonts_url() {

	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
	 * supported by Roboto, translate this to 'off'. Do not translate
	 * into your own language.
	 */
	$roboto = _x( 'on', 'Roboto font: on or off', 'sonsa' );

	if ( 'off' !== $roboto ) {
		
		$font_families = array();

		$font_families[] = 'Roboto:400,700,400italic,700italic';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		
		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
		
	}

	return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function sonsa_scripts() {
	
	// Enqueue fonts.
	wp_enqueue_style( 'sonsa-fonts', sonsa_fonts_url(), array(), null );
	
	// Add Genericons font, used in the main stylesheet.
	wp_enqueue_style( 'genericons', trailingslashit( get_template_directory_uri() ) . 'genericons/genericons.css', array(), '3.3.1' );
	
	// Enqueue parent theme styles if using child theme.
	if ( is_child_theme() ) {
		wp_enqueue_style( 'sonsa-parent-style', trailingslashit( get_template_directory_uri() ) . 'style.css', array(), SONSA_VERSION );
	}
	
	// Enqueue active theme styles.
	wp_enqueue_style( 'sonsa-style', get_stylesheet_uri(), array(), sonsa_theme_version() );
	
	// Load the Internet Explorer 9 specific stylesheet.
	wp_enqueue_style( 'sonsa-ie9', trailingslashit( get_template_directory_uri() ) . 'css/ie9.css', array( 'sonsa-style' ), '20161229' );
	wp_style_add_data( 'sonsa-ie9', 'conditional', 'IE 9' );
	
	// Enqueue perfect scrollbar script.
	wp_enqueue_script( 'sonsa-perfect-scrollbar', trailingslashit( get_template_directory_uri() ). 'js/perfect-scrollbar.js', array(), '20161229', true );
	
	// Load the matchMedia polyfill.
	wp_enqueue_script( 'sonsa-matchmedia-addlistener', trailingslashit( get_template_directory_uri() ) . 'js/matchMedia.addListener.js', array( 'sonsa-matchmedia' ), '20161229', true );
	wp_script_add_data( 'sonsa-matchmedia-addlistener', 'conditional', 'IE 9' );
	
	wp_enqueue_script( 'sonsa-matchmedia', trailingslashit( get_template_directory_uri() ) . 'js/matchMedia.js', array(), '20161229', true );
	wp_script_add_data( 'sonsa-matchmedia', 'conditional', 'IE 9' );
	
	// Enqueue enquire script.
	wp_enqueue_script( 'sonsa-enquire', trailingslashit( get_template_directory_uri() ). 'js/enquire.js', array( 'sonsa-matchmedia-addlistener', 'sonsa-matchmedia' ), '20161229', true );
	
	// Enqueue theme scripts.
	wp_enqueue_script( 'sonsa-scripts', trailingslashit( get_template_directory_uri() ) . 'js/scripts.js', array( 'sonsa-perfect-scrollbar', 'sonsa-enquire' ), '20161229', true );
	
	// Enqueue theme settings.
	wp_enqueue_script( 'sonsa-settings', trailingslashit( get_template_directory_uri() ) . 'js/settings.js', array( 'jquery' ), '20161229', true );
	wp_localize_script( 'sonsa-settings', 'screenReaderText', array(
		'expand'         => '<span class="screen-reader-text">' . esc_html__( 'Expand sidebar', 'sonsa' ) . '</span>',
		'collapse'       => '<span class="screen-reader-text">' . esc_html__( 'Collapse sidebar', 'sonsa' ) . '</span>',
	) );
	
	// Enqueue skip link script.
	wp_enqueue_script( 'sonsa-skip-link-focus-fix', trailingslashit( get_template_directory_uri() ). 'js/skip-link-focus-fix.js', array(), '20161229', true );
		
	// Enqueue comment reply script.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'sonsa_scripts' );

/**
 * Get theme version number, works also for child themes.
 *
 * @since  1.1.0
 * @return string $theme_version
 */
function sonsa_theme_version() {
	$theme = is_child_theme() ? wp_get_theme( get_stylesheet() ) : wp_get_theme( get_template() );
	return $theme_version = $theme->get( 'Version' );
}

/**
 * JavaScript Detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @author    Twenty Fifteen
 * @copyright Automattic
 * @license   http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 *
 * @since 1.0.0
 */
function sonsa_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'sonsa_javascript_detection', 0 );

/**
 * Add featured image as background image to post navigation elements.
 *
 * @author    Twenty Fifteen
 * @copyright Automattic
 * @license   http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 *
 * @since 1.0.0
 * @see wp_add_inline_style()
 */
function sonsa_post_nav_background() {
	
	if ( ! is_single() ) {
		return;
	}
	
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );
	$css      = '';
	
	if ( is_attachment() && 'attachment' == $previous->post_type ) {
		return;
	}
	
	if ( $previous &&  has_post_thumbnail( $previous->ID ) ) {
		$prevthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $previous->ID ), 'sonsa-thumbnail' );
		$css .= '
			@media screen and (min-width: 300px) {
				.post-navigation .nav-previous { background-image: url(' . esc_url_raw( $prevthumb[0] ) . '); }
				.post-navigation .nav-previous { background-repeat: no-repeat; }
				.post-navigation .nav-previous { background-position: left center; }
				.rtl .post-navigation .nav-previous { background-position: right center; }
				.post-navigation .nav-previous { padding-left: 0; }
				.post-navigation .nav-previous a { padding-left: 171px; }
				.rtl .post-navigation .nav-previous { padding-right: 0; }
				.rtl .post-navigation .nav-previous a { padding-right: 171px; }
				.rtl .post-navigation .nav-previous a { padding-left: 0; }
			}
			
			@media screen and (min-width: 960px) {
				
				.post-navigation {
					margin-left: 0;
				}
				.rtl .post-navigation {
					margin-right: 0;
				}
				
				.post-navigation .nav-previous::before {
					box-shadow: inset 10px 0 5px -7px rgba( 0, 0, 0, 0.08 );
					display: block;
					content: "";
					position: absolute;
					width: 100%;
					height: 100%;
					z-index: -1;
				}
			}
			
		';
	}
	
	if ( $next && has_post_thumbnail( $next->ID ) ) {
		$nextthumb = wp_get_attachment_image_src( get_post_thumbnail_id( $next->ID ), 'sonsa-thumbnail' );
		$css .= '
			@media screen and (min-width: 300px) {
				.post-navigation .nav-next { background-image: url(' . esc_url_raw( $nextthumb[0] ) . '); }
				.post-navigation .nav-next { background-repeat: no-repeat; }
				.post-navigation .nav-next { background-position: right center; }
				.rtl .post-navigation .nav-next { background-position: left center; }
				.post-navigation .nav-next { padding-right: 0; }
				.post-navigation .nav-next a { padding-right: 171px; }
				.rtl .post-navigation .nav-next { padding-left: 0; }
				.rtl .post-navigation .nav-next a { padding-left: 171px; }
				.rtl .post-navigation .nav-next a { padding-right: 0; }
			}
		';
	}
	
	if ( $previous &&  has_post_thumbnail( $previous->ID ) || $next && has_post_thumbnail( $next->ID ) ) {
		$css .= '
			@media screen and (min-width: 300px) {
				.post-navigation .nav-previous a, .post-navigation .nav-next a { min-height: 150px; }
				.post-navigation a { padding-top: 21px; padding-bottom: 21px }
			}
		';
	
	}
	
	wp_add_inline_style( 'sonsa-style', $css );
	
}
add_action( 'wp_enqueue_scripts', 'sonsa_post_nav_background' );

/**
 * Add body classes.
 *
 * @param  array  $classes  body classes.
 * @return array  $classes  body classes.
 * @since  1.0.0
 */
function sonsa_extra_body_classes( $classes ) {
	
	// Add the '.custom-header-image' class if the user is using a custom header image.
	if ( get_header_image() ) {
		$classes[] = 'custom-header-image';
	}
	
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}
	
	// Adds a class to 404 page if there is image set in the Customizer.
	if ( is_404() && get_theme_mod( '404_image' ) ) {
		$classes[] = 'has-404-image';
	}
	
	// Adds a class if there is default feature image set in the Customizer.
	if ( get_theme_mod( 'default_post_image' ) ) {
		$classes[] = 'has-default-feature-image';
	}
	
    return $classes;
	
}
add_filter( 'body_class', 'sonsa_extra_body_classes' );

/**
 * Change excerpt length.
 *
 * @since 1.0.0
 */
function sonsa_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'sonsa_excerpt_length' );

/**
 * Change [...] to ... Read more.
 *
 * @since 1.0.0
 */
function sonsa_excerpt_more() {

	$more = esc_html_x( '&hellip;', 'mark after excerpt', 'sonsa' );
	return $more;

}
add_filter( 'excerpt_more', 'sonsa_excerpt_more' );

/**
 * Add an HTML class to MediaElement.js container elements to aid styling.
 *
 * Extends the core _wpmejsSettings object to add a new feature via the
 * MediaElement.js plugin API.
 *
 * @author     Brady Vercher
 * @copyright  Brady Vercher
 * @link       http://www.cedaro.com/blog/customizing-mediaelement-wordpress/
 * @license    http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 *
 * @since  1.0.0
 * @return void
 */
function sonsa_mejs_add_container_class() {
	
	// Check do we have media element.
	if ( ! wp_script_is( 'mediaelement', 'done' ) ) {
		return;
	}

	?>
	<script>
	(function() {
		var settings = window._wpmejsSettings || {};
		settings.features = settings.features || mejs.MepDefaults.features;
		settings.features.push( 'SonsaClass' );

		MediaElementPlayer.prototype.buildSonsaClass = function( player ) {
			player.container.addClass( 'sonsa-mejs-container' );
		};
	})();
	</script>
	<?php
}
add_action( 'wp_print_footer_scripts', 'sonsa_mejs_add_container_class' );

/**
 * Use a template for individual comment output.
 *
 * @param object $comment Comment to display.
 * @param int    $depth   Depth of comment.
 * @param array  $args    An array of arguments.
 *
 * @since 1.0.0
 */
function sonsa_comment_callback( $comment, $args, $depth ) {
	include( locate_template( 'comment.php') );
}

/**
 * Function for grabbing a WP nav menu name based on theme location.
 *
 * @since  1.0.0
 * @access public
 * @param  string  $location
 * @return string
 */
function sonsa_get_menu_name( $location ) {
	
	$locations = get_nav_menu_locations();
	return isset( $locations[ $location ] ) ? wp_get_nav_menu_object( $locations[ $location ] )->name : '';
	
}

/**
 * Implement the Custom Background feature.
 */
require get_template_directory() . '/inc/custom-background.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Schema.org file.
 */
require get_template_directory() . '/inc/schema.php';

/**
 * Load media grabber file.
 */
require get_template_directory() . '/inc/media-grabber.php';

/**
 * Load post format file.
 */
require get_template_directory() . '/inc/functions-formats.php';

/**
 * Load chat format file.
 */
require get_template_directory() . '/inc/class-chat.php';

/**
 * Load archive filters file.
 */
require get_template_directory() . '/inc/archive-filters.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Add theme settings for license.
 */
function sonsa_theme_updater() {
	require_once( get_template_directory() . '/theme-updater/theme-updater.php' );
}
add_action( 'after_setup_theme', 'sonsa_theme_updater' );